==> stability_0.3.0.tar.gz: stability/R/stab_asv.R <==
if(getRversion() >= "2.15.1"){
  utils::globalVariables(c(
     "rASD"
  ))
}

#' @name    stab_asv
#' @aliases stab_asv
#' @title   Additive Main Effects and Multiplicative Interacion Stability Value
#' @description Additive ANOVA for Genotypes by Environment Interaction (GEI) model
#'
#' @param .data  data.frame
#' @param .y     Response Variable
#' @param .rep   Replication Factor
#' @param .gen   Genotypes Factor
#' @param .env   Environment Factor
#'
#' @return Additive ANOVA
#'
#' @author
#' \enumerate{
#'          \item Muhammad Yaseen (\email{myaseen208@@gmail.com})
#'          \item Kent M. Edkridge (\email{keskridge1@@unl.edu})
#'          }
#'
#' @references
#'  Singh, R. K. and Chaudhary, B. D. (2004) \emph{Biometrical Methods in Quantitative Genetic Analysis}.
#'              New Delhi: Kalyani.
#'
#' @import dplyr
#' @import tibble
#' @importFrom magrittr %>%
#'
#' @export
#'
#' @examples
#' data(ge_data)
#' YieldASV <-
#'      stab_asv(
#'             .data = ge_data
#'           , .y    = Yield
#'           , .rep  = Rep
#'           , .gen  = Gen
#'           , .env  = Env
#'       )
#' YieldASV
#'
stab_asv <- function(.data, .y, .rep, .gen, .env) {
  UseMethod("stab_asv")
}

#' @export
#' @rdname stab_asv

stab_asv.default <-
  function(.data, .y, .rep, .gen, .env){

    Y   <- enquo(.y)
    Rep <- enquo(.rep)
    G   <- enquo(.gen)
    E   <- enquo(.env)

    g <- length(levels(.data$G))
    e <- length(levels(.data$E))
    r <- length(levels(.data$Rep))

    GMeans <-
      ge_means(
         .data  = .data
        , .y    = !! Y
        , .gen  = !! G
        , .env  = !! E
      )$g_means

    names(GMeans) <- c("Gen", "Mean")


    GE.Effs <-
      ge_effects(
        .data  = .data
        , .y    = !! Y
        , .gen  = !! G
        , .env  = !! E
      )$ge_effects

    SVD <- svd(GE.Effs)
    PC <- SVD$u %*% diag(sqrt(SVD$d))
    dimnames(PC) <- list(row.names(GE.Effs), paste0("PC", 1:e))

    Lambda  <- SVD$d

    ASD <-
      GMeans %>%
      dplyr::mutate(
          ASD   = sqrt((Lambda[1]/Lambda[2])*PC[, 1, drop = FALSE]^2 + PC[, 2, drop = FALSE]^2)
        , rMean = min_rank(desc(Mean))
        , rASD  = min_rank(ASD)
        , YSI   = rMean + rASD
      )

    return(list(
          ASD = ASD
           ))
  }

==> stability_0.6.0.tar.gz: stability/R/stab_asv.R <==
if(getRversion() >= "2.15.1"){
  utils::globalVariables(c(
     "rASD"
  ))
}

#' @name    stab_asv
#' @aliases stab_asv
#' @title   Additive Main Effects and Multiplicative Interacion Stability Value
#' @description Additive ANOVA for Genotypes by Environment Interaction (GEI) model
#'
#' @param .data  data.frame
#' @param .y     Response Variable
#' @param .rep   Replication Factor
#' @param .gen   Genotypes Factor
#' @param .env   Environment Factor
#'
#' @return Additive ANOVA
#'
#' @author
#' \enumerate{
#'          \item Muhammad Yaseen (\email{myaseen208@@gmail.com})
#'          \item Kent M. Edkridge (\email{keskridge1@@unl.edu})
#'          }
#'
#' @references
#'  Singh, R. K. and Chaudhary, B. D. (2004) \emph{Biometrical Methods in Quantitative Genetic Analysis}.
#'              New Delhi: Kalyani.
#'
#' @import dplyr
#' @import tibble
#' @importFrom magrittr %>%
#'
#' @export
#'
#' @examples
#' data(ge_data)
#' YieldASV <-
#'      stab_asv(
#'             .data = ge_data
#'           , .y    = Yield
#'           , .rep  = Rep
#'           , .gen  = Gen
#'           , .env  = Env
#'       )
#' YieldASV
#'
stab_asv <- function(.data, .y, .rep, .gen, .env) {
  UseMethod("stab_asv")
}

#' @export
#' @rdname stab_asv

stab_asv.default <-
  function(.data, .y, .rep, .gen, .env){

    Y   <- deparse(substitute(.y))
    Rep <- deparse(substitute(.rep))
    G   <- deparse(substitute(.gen))
    E   <- deparse(substitute(.env))


    g <- length(levels(.data[[G]]))
    e <- length(levels(.data[[E]]))
    r <- length(levels(.data[[Rep]]))

    g_means <-
      .data %>%
      dplyr::group_by(!!rlang::sym(G)) %>%
      dplyr::summarize(Mean = mean(!!rlang::sym(Y)))


    ge_means <-
      .data %>%
      dplyr::group_by(!!rlang::sym(G), !!rlang::sym(E)) %>%
      dplyr::summarize(GE.Mean = mean(!!rlang::sym(Y))) %>%
      tidyr::spread(key = E, value = GE.Mean)

    ge_means1 <- as.matrix(ge_means[, -1])
    rownames(ge_means1) <- c(ge_means[, 1])[[1]]

    gge_effects <-
      sweep(
        x      = ge_means1
        , MARGIN = 2
        , STATS  = colMeans(ge_means1)
      )

    ge_effects <-
      sweep(
        x      = gge_effects
        , MARGIN = 1
        , STATS  = rowMeans(gge_effects)
      )


    SVD <- svd(ge_effects)
    PC <- SVD$u %*% diag(sqrt(SVD$d))
    dimnames(PC) <- list(row.names(ge_effects), paste0("PC", 1:e))

    Lambda  <- SVD$d

    ASD <-
      g_means %>%
      dplyr::mutate(
          ASD   = sqrt((Lambda[1]/Lambda[2])*PC[, 1, drop = FALSE]^2 + PC[, 2, drop = FALSE]^2)
        , rMean = min_rank(desc(Mean))
        , rASD  = min_rank(ASD)
        , YSI   = rMean + rASD
      )

    return(list(
           ASD = ASD
           ))
  }
